@@ -226,7 +226,7 @@ eel_string_picker_set_string_list (EelStringPicker *string_picker,
 {
 	guint i;
 	GtkWidget *menu_item;
-	char *item_label;
+	const char *item_label;
 
 	g_return_if_fail (EEL_IS_STRING_PICKER (string_picker));
 
@@ -250,7 +250,7 @@ eel_string_picker_set_string_list (EelStringPicker *string_picker,
 	
 	if (eel_string_list_get_length (string_picker->detail->string_list) > 0) {
 		for (i = 0; i < eel_string_list_get_length (string_picker->detail->string_list); i++) {
-			item_label = eel_string_list_nth (string_picker->detail->string_list, i);
+			item_label = eel_string_list_peek_nth (string_picker->detail->string_list, i);
 			g_assert (item_label != NULL);
 			
 			if (eel_str_is_equal (item_label, EEL_STRING_PICKER_SEPARATOR_STRING)) {
